@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.37 2003/05/22 16:56:59 bazsi Exp $ */
+ * $Id: io.c,v 1.38 2004/01/12 15:58:34 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -896,25 +896,6 @@ static int connect_inet_socket(struct address_info *c, int fd)
 	return 0;
 }
 
-struct inet_address_info *make_inet_address_c(const char *host,
-                                         const char *port)
-{
-	int portno = get_portno(port, "tcp");
-	if (portno < 0)
-		return 0;
-	else
-	{
-		NEW(inet_address_info, info);
-      
-		info->super.family = AF_INET;
-		info->super.bind_socket = bind_inet_socket;
-		info->super.connect_socket = connect_inet_socket;
-		info->port = portno;
-		info->ip = host ? c_format("%z", host) : NULL;
-
-		return info;
-	}
-}
 
 struct inet_address_info *make_inet_address(struct ol_string *host, UINT32 port)
 {
@@ -929,6 +910,17 @@ struct inet_address_info *make_inet_address(struct ol_string *host, UINT32 port)
 	return info;
 }
 
+struct inet_address_info *make_inet_address_c(const char *host, const char *port)
+{
+	int portno = get_portno(port, "tcp");
+	if (portno < 0)
+		return 0;
+	else
+	{
+		return make_inet_address(host ? c_format("%z", host) : NULL, portno);
+	}
+}
+
 /* unix_address_info */
 
 static int unix_address2sockaddr_un(struct address_info *c, int sasize, struct sockaddr *sa)
